##  Configuring the Dashboard
**Tip**
Configure the architecture executive dashboard before you start using it.
To limit the scope of data used in KPI calculations, configure the global filter and custom views for the dashboard. For detailed information, visit [Configuring the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Configure filters for the architecture executive dashboard to limit the scope of data used in KPI calculations.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioba15979f75e14b48b2a95b3224a78b63_LowRes.png)
Configuring the Architecture Executive Dashboard
